Crate tor_rpc_connect

Crate tor_rpc_connect 

tor-rpc-connect

Functionality related to RPC connect points.

Overview

A “connect point” is Toml string that describes how an RPC client should connect to an RPC server; and how an RPC server should wait for client connections.

This crate implements parsing for the format, and facilities to either connect to an RPC server or listen as an RPC server given a connect point.

License: MIT OR Apache-2.0

Modules

auth
Representations for types of required RPC connections.
clientrpc-client
Client operations for working with connect points.
load
Functionality for reading a connect point from a file, and verifying that its permissions are correct.
serverrpc-server
Server operations for working with connect points.

Structs

ParsedConnectPoint
A connect point, as deserialized from TOML.
ResolvedConnectPoint
A connect point, with all paths resolved.

Enums

ClientErrorAction
An action that an RPC client should take when a connect point fails.
ConnectError
A failure to connect or bind to a ResolvedConnectPoint.
ResolveError
A failure from ParsedConnectPoint::resolve().
SuperuserPermission
An enum to reflect whether an authenticated connection to a connect point is allowed to acquire superuser (admin) capabilities.

Constants

SYSTEM_DEFAULT_CONNECT_POINT
Default connect point for a system-wide Arti instance.
USER_DEFAULT_CONNECT_POINT
Default connect point for a user-owned Arti instance.

Traits

HasClientErrorAction
An error that has a ClientErrorAction.