#[non_exhaustive]pub struct Connection {
pub stream: Stream,
pub auth: RpcAuth,
}Expand description
Information about an initial connection to a connect point.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.stream: StreamA successfully connected stream.
At the time this is returned, authentication has not yet completed.
auth: RpcAuthInformation about how to authenticate.