pub(crate) enum ConnectPointEnum<R: Addresses> {
Connect(Connect<R>),
Builtin(Builtin),
}Expand description
Implementation type for a connect point.
This type is hidden so that the enum fields remain private.
It is parameterized on a Addresses trait,
to indicate whether it is in resolved or unresolved form.
Variants
Connect(Connect<R>)
Connect by opening a socket to a general::SocketAddr
Builtin(Builtin)
Connect by some built-in mechanism.
(Or, in the case of Abort, do not connect at all.)
Implementations
Sourceimpl<R: Addresses> ConnectPointEnum<R>
impl<R: Addresses> ConnectPointEnum<R>
Sourcefn superuser_permission(&self) -> SuperuserPermission
fn superuser_permission(&self) -> SuperuserPermission
Check whether authenticating this connect point grants superuser permission.
Sourcefn is_explicit_abort(&self) -> bool
fn is_explicit_abort(&self) -> bool
Return true if this connect point is an explicit abort.