pub(crate) struct AddrWithStr<A>{
string: String,
addr: A,
}Expand description
Represent an address type along with the string it was decoded from.
We use this type in connect points because, for some kinds of authentication, we need the literal input string that created the address.
Fields
string: StringThe string representation of the address.
For inet addresses, this is the value that appeared in the configuration. For unix domain sockets, this is the value that appeared in the configuration, after shell expansion.
addr: AThe address itself.
Implementations
Sourceimpl<A> AddrWithStr<A>
impl<A> AddrWithStr<A>
Sourcepub(crate) fn as_str(&self) -> &str
pub(crate) fn as_str(&self) -> &str
Return the string representation of this address, for use in the authentication handshake.
Sourcepub(crate) fn set_string_from<B: Clone + Debug>(
&mut self,
other: &AddrWithStr<B>,
)
pub(crate) fn set_string_from<B: Clone + Debug>( &mut self, other: &AddrWithStr<B>, )
Replace the string representation of this address with the one in other.
Sourceimpl AddrWithStr<String>
impl AddrWithStr<String>
Sourcepub(crate) fn resolve(
&self,
resolver: &CfgPathResolver,
) -> Result<AddrWithStr<SocketAddr>, ResolveError>
pub(crate) fn resolve( &self, resolver: &CfgPathResolver, ) -> Result<AddrWithStr<SocketAddr>, ResolveError>
Convert an AddrWithStr<String> into its substituted form.