pub(crate) struct InetAutoAddress {
bind: Option<IpAddr>,
}Expand description
Instructions to bind to an address chosen by the OS.
Fields
bind: Option<IpAddr>The address that the relay should bind to, or None if any loopback address is okay.
Must be a loopback address.
Implementations
Sourceimpl InetAutoAddress
impl InetAutoAddress
Sourcefn bind_to_addresses(&self) -> Vec<SocketAddr>
fn bind_to_addresses(&self) -> Vec<SocketAddr>
Return a list of addresses to bind to.
Sourcepub(crate) fn validate_parsed_address(
&self,
addr: &SocketAddr,
) -> Result<(), ConnectError>
pub(crate) fn validate_parsed_address( &self, addr: &SocketAddr, ) -> Result<(), ConnectError>
Having parsed addr, make sure it is a possible instantiation of this address.
Return an error if it is not.