pub struct ParsedConnectPoint(ConnectPointEnum<Unresolved>);Expand description
A connect point, as deserialized from TOML.
Connect points tell an RPC client how to reach an RPC server, and tell an RPC server where and how to listen for connections for RPC clients.
This type may have members containing symbolic paths, such as
${USER_HOME} or ${ARTI_LOCAL_STATE}.
To convert these paths to a usable format,
invoke ParsedConnectPoint::resolve() on this object.
Tuple Fields
0: ConnectPointEnum<Unresolved>Implementations
Sourceimpl ParsedConnectPoint
impl ParsedConnectPoint
Sourcepub fn resolve(
&self,
resolver: &CfgPathResolver,
) -> Result<ResolvedConnectPoint, ResolveError>
pub fn resolve( &self, resolver: &CfgPathResolver, ) -> Result<ResolvedConnectPoint, ResolveError>
Sourcepub fn superuser_permission(&self) -> SuperuserPermission
pub fn superuser_permission(&self) -> SuperuserPermission
Check whether authenticating this connect point grants superuser permission.
Sourcepub fn is_explicit_abort(&self) -> bool
pub fn is_explicit_abort(&self) -> bool
Return true if this connect point is an explicit abort.
Sourceimpl ParsedConnectPoint
impl ParsedConnectPoint
Sourcepub fn load_dir<'a>(
path: &Path,
mistrust: &Mistrust,
options: &'a HashMap<PathBuf, LoadOptions>,
) -> Result<ConnPointIterator<'a>, LoadError>
pub fn load_dir<'a>( path: &Path, mistrust: &Mistrust, options: &'a HashMap<PathBuf, LoadOptions>, ) -> Result<ConnPointIterator<'a>, LoadError>
Load all the connect files from a directory.
The directory, and individual files loaded within it,
must satisfy mistrust.
Within a directory:
- only filenames ending with
.tomlare considered. - on unix, filenames beginning with
.are ignored. - files are considered in lexicographic order.
Use options as a set of per-file options
mapping the names of files within path
to rules for reading them.
Return an iterator yielding, for each element of the directory,
its filename, and a ParsedConnectPoint or an error.