#[non_exhaustive]pub enum ConnectError {
Io(Arc<Error>),
ExplicitAbort,
LoadCookie(CookieAccessError),
UnsupportedSocketType,
UnsupportedAuthType,
AfUnixSocketPathAccess(Error),
SocketAddressFileAccess(Error),
SocketAddressFileJson(Arc<Error>),
SocketAddressFileContent(AddrParseError),
SocketAddressFileMismatch,
AlreadyLocked,
Internal(String),
}Expand description
A failure to connect or bind to a ResolvedConnectPoint.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Io(Arc<Error>)
We encountered an IO error while actually opening our socket.
ExplicitAbort
The connect point told us to abort explicitly.
LoadCookie(CookieAccessError)
We couldn’t load the cookie file for cookie authentication.
UnsupportedSocketType
We were told to connect to a socket type that we don’t support.
UnsupportedAuthType
We were told to connect using an auth type that we don’t support.
AfUnixSocketPathAccess(Error)
Unable to access the location of an AF_UNIX socket.
SocketAddressFileAccess(Error)
Unable to access the location of socket_address_file.
SocketAddressFileJson(Arc<Error>)
We couldn’t parse the JSON contents of a socket address file.
SocketAddressFileContent(AddrParseError)
We couldn’t parse the address in a socket address file.
SocketAddressFileMismatch
We found an address in the socket address file that didn’t match the connect point.
AlreadyLocked
Another process was holding a lock for this connect point, so we couldn’t bind to it.
Internal(String)
We encountered an internal logic error.