#[non_exhaustive]pub enum SuperuserPermission {
Allowed,
NotAllowed,
}Expand description
An enum to reflect whether an authenticated connection to a connect point is allowed to acquire superuser (admin) capabilities.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Allowed
The connection may acquire superuser capabilities.
NotAllowed
The connection may not acquire superuser capabilities.