net_error_action

Function net_error_action 

pub(crate) fn net_error_action(err: &Error) -> ClientErrorAction
Return the ClientErrorAction for an IO error encountered while opening a socket.

Note that this is not an implementation of HasClientErrorAction: We want to decline on a different set of errors for fs operation.