pub struct LoadOptionsBuilder {
disable: Option<bool>,
}Expand description
Builder for LoadOptions.
Fields
disable: Option<bool>If true, do not try to read the file.
Implementations
Sourceimpl LoadOptionsBuilder
impl LoadOptionsBuilder
Sourcepub fn build(&self) -> Result<LoadOptions, LoadOptionsBuilderError>
pub fn build(&self) -> Result<LoadOptions, LoadOptionsBuilderError>
Sourcefn create_empty() -> Self
fn create_empty() -> Self
Create an empty builder, with all fields set to None or PhantomData.