pub struct ResolvedConnectPoint(/* private fields */);Expand description
A connect point, with all paths resolved.
Connect points tell an RPC client how to reach an RPC server, and tell an RPC server where and how to listen for connections for RPC clients.
This type is returned by ParsedConnectPoint::resolve(),
and can be used to connect or bind.
Implementations
Sourceimpl ResolvedConnectPoint
impl ResolvedConnectPoint
Sourcepub fn connect(&self, mistrust: &Mistrust) -> Result<Connection, ConnectError>
Available on crate feature rpc-client only.
pub fn connect(&self, mistrust: &Mistrust) -> Result<Connection, ConnectError>
rpc-client only.Open a new connection to the RPC server designated by this connect point.
On success, return a Connection structure containing a newly open socket, and instructions about how to authenticate on that socket.
Sourceimpl ResolvedConnectPoint
impl ResolvedConnectPoint
Sourcepub fn superuser_permission(&self) -> SuperuserPermission
pub fn superuser_permission(&self) -> SuperuserPermission
Check whether authenticating this connect point grants superuser permission.
Sourcepub fn is_explicit_abort(&self) -> bool
pub fn is_explicit_abort(&self) -> bool
Return true if this connect point is an explicit abort.
Sourceimpl ResolvedConnectPoint
impl ResolvedConnectPoint