pub(crate) fn fs_error_action(err: &Error) -> ClientErrorActionExpand description
Return the ClientErrorAction for an IO error encountered while accessing the filesystem.
Note that this is not an implementation of HasClientErrorAction:
We want to decline on a different set of errors for network operation.